import {FileMetas, PlayerEvents, PlayerOptions, PlayOptions, Position} from "./model.ts";
import Emittery from "emittery";

/**
 * 文件播放引擎
 */
export interface Engine {
    play(metas: FileMetas, options: Partial<PlayOptions>): Promise<void>;

    prev(): Promise<void>;

    next(): Promise<void>;

    goto(pos: Position): Promise<void>;

    destroy(): Promise<void>;
}


export abstract class BaseEngine {

    protected emitter: Emittery<PlayerEvents>;

    protected readonly container: HTMLElement;

    protected options: Partial<PlayerOptions>;

    constructor(emitter: Emittery<PlayerEvents>, container: HTMLElement, options?: Partial<PlayerOptions>) {
        this.emitter = emitter;
        this.container = container;
        this.options = options ? options : {};
    }

    public createFrame(): HTMLIFrameElement {
        const frame = document.createElement('iframe');
        frame.name = 'cfp-iframe';
        frame.setAttribute('style', 'position:absolute;top:0;left:0;width:100%;height:100%;border:0');
        return  frame;
    }
}
