import Postmate from "postmate";
import {FileMetas, PlayOptions, Position} from "./model.ts";
import {BaseEngine, Engine} from "./engine.ts";

export class ImageEngine extends BaseEngine implements Engine {

    private postmate?: Postmate.ParentAPI;

    public async play(metas: FileMetas, options: Partial<PlayOptions>): Promise<void> {
        return new Promise<void>(async (resolve) => {
            const url =  this.options.imageEngineIframeUrl
                ? this.options.imageEngineIframeUrl
                : `${this.options.engineBaseUrl ? this.options.engineBaseUrl : ''}/cf-player/image-engine/index.html`;

            const postmate = await new Postmate({
                container: this.container,
                // @ts-ignore
                frame: this.createFrame(),
                url: url,
                model: {
                    metas: metas,
                    defaultPage: options.defaultPage ? options.defaultPage : 1,
                    vertical: options.vertical ? options.vertical : false,
                }
            });

            let ready = false;
            postmate.on("paginationChange", (data) => {
                this.emitter.emit("paginationChange", data);
                if (!ready) {
                    ready = true;
                    setTimeout(() => {
                        resolve();
                    }, 500);
                }
            });
            this.postmate = postmate;
        });
    }

    public async prev(): Promise<void> {
        if (!this.postmate) {
            throw new Error("No postmate handshake.");
        }
        await this.postmate.get("prev") as unknown as Promise<void>;
    }

    public async next(): Promise<void> {
        if (!this.postmate) {
            throw new Error("No postmate handshake.");
        }
        await this.postmate.get("next") as unknown as Promise<void>;
    }

    public async goto(pos: Position): Promise<void> {
        if (!this.postmate) {
            throw new Error("No postmate handshake.");
        }
        this.postmate.call("goto", pos);
    }

    public async destroy(): Promise<void> {
        if (!this.postmate) {
            return ;
        }
        this.postmate.destroy();
    }
}
