import Postmate from "postmate";
import {FileMetas, PlayOptions, Position} from "./model.ts";
import {BaseEngine, Engine} from "./engine.ts";

export class PresentationEngine extends BaseEngine implements Engine {

    private parent?: Postmate.ParentAPI;

    public async play(metas: FileMetas, options: Partial<PlayOptions>): Promise<void> {
        return new Promise<void>(async (resolve) => {
            const url =  this.options.presentationAnimationEngineIframeUrl
                ? this.options.presentationAnimationEngineIframeUrl
                : `${this.options.engineBaseUrl ? this.options.engineBaseUrl : ''}/cf-player/presentation-engine/index.html`;

            const parent = await new Postmate({
                container: this.container,
                // @ts-ignore
                frame: this.createFrame(),
                url: url,
                model: {
                    playMetas: metas.animation,
                    defaultPage: options.defaultPage ? options.defaultPage : 1,
                    defaultStep: options.defaultStep ? options.defaultStep : 1,
                }
            });
            let ready = false;
            parent.on("paginationChange", (data) => {
                this.emitter.emit("paginationChange", Object.assign(data, {total: metas.page}));
                if (!ready) {
                    ready = true;
                    resolve();
                }
            });
            this.parent = parent;
        });
    }

    public async prev(): Promise<void> {
        if (!this.parent) {
            throw new Error("No postmate handshake.");
        }
        await this.parent.get("prev") as unknown as Promise<void>;
    }

    public async next(): Promise<void> {
        if (!this.parent) {
            throw new Error("No postmate handshake.");
        }
        await this.parent.get("next") as unknown as Promise<void>;
    }

    public async goto(pos: Position): Promise<void> {
        if (!this.parent) {
            throw new Error("No postmate handshake.");
        }
        pos.step = pos.step ? pos.step : 1;
        this.parent.call("goto", pos);
    }

    public async destroy(): Promise<void> {
        if (!this.parent) {
            return ;
        }
        this.parent.destroy();
    }
}
